@@ -13,7 +13,6 @@ enum {
 	DMEAS,
 	DREF,
 	DGPRS,
-	DNS,
 	DLLC,
 	DSNDCP,
 	DSLHC,
@@ -28,6 +27,7 @@ enum {
 	DGTP,
 	DOBJ,
 	DRIM,
+	DRA, /* Routing Area handling */
 	Debug_LastEntry,
 };
 
